@@ -27,16 +27,10 @@
 #include "CG_ref.hpp"
 #include "mytimer.hpp"
 #include "ComputeSPMV_ref.hpp"
-#include "ComputeSYMGS_ref.hpp"
+#include "ComputeMG_ref.hpp"
 #include "ComputeDotProduct_ref.hpp"
 #include "ComputeWAXPBY_ref.hpp"
 
-#ifndef HPCG_NOMPI
-#include "ExchangeHalo.hpp"
-#endif
-
-using std::endl;
-
 
 // Use TICK and TOCK to time a code section in MATLAB-like fashion
 #define TICK()  t0 = mytimer() //!< record current time in 't0'
@@ -45,7 +39,6 @@ using std::endl;
 /*!
   Reference routine to compute an approximate solution to Ax = b
 
-  @param[in]    geom The description of the problem's geometry.
   @param[inout] A    The known system matrix
   @param[inout] data The data structure with all necessary CG vectors preallocated
   @param[in]    b    The known right hand side vector
@@ -62,7 +55,7 @@ using std::endl;
 
   @see CG()
 */
-int CG_ref(const Geometry & geom, const SparseMatrix & A, CGData & data, const double * const b, double * const x,
+int CG_ref(const SparseMatrix & A, CGData & data, const Vector & b, Vector & x,
     const int max_iter, const double tolerance, int & niters, double & normr, double & normr0,
     double * times, bool doPreconditioning) {
 
@@ -72,18 +65,18 @@ int CG_ref(const Geometry & geom, const SparseMatrix & A, CGData & data, const d
 
 
   double t0 = 0.0, t1 = 0.0, t2 = 0.0, t3 = 0.0, t4 = 0.0, t5 = 0.0;
-#ifndef HPCG_NOMPI
-  double t6 = 0.0;
-#endif
+//#ifndef HPCG_NOMPI
+//  double t6 = 0.0;
+//#endif
 
   local_int_t nrow = A.localNumberOfRows;
 
-  double * r = data.r; // Residual vector
-  double * z = data.z; // Preconditioned residual vector
-  double * p = data.p; // Direction vector (in MPI mode ncol>=nrow)
-  double * Ap = data.Ap;
+  Vector & r = data.r; // Residual vector
+  Vector & z = data.z; // Preconditioned residual vector
+  Vector & p = data.p; // Direction vector (in MPI mode ncol>=nrow)
+  Vector & Ap = data.Ap;
 
-  if (!doPreconditioning && geom.rank==0) HPCG_fout << "WARNING: PERFORMING UNPRECONDITIONED ITERATIONS" << endl;
+  if (!doPreconditioning && A.geom->rank==0) HPCG_fout << "WARNING: PERFORMING UNPRECONDITIONED ITERATIONS" << std::endl;
 
 #ifdef HPCG_DEBUG
   int print_freq = 1;
@@ -91,16 +84,13 @@ int CG_ref(const Geometry & geom, const SparseMatrix & A, CGData & data, const d
   if (print_freq<1)  print_freq=1;
 #endif
   // p is of length ncols, copy x to p for sparse MV operation
-  ComputeWAXPBY_ref(nrow, 1.0, x, 0.0, x, p);
-#ifndef HPCG_NOMPI
-  TICK(); ExchangeHalo(A,p); TOCK(t6);
-#endif
-  ComputeSPMV_ref(A, p, Ap);
-  ComputeWAXPBY_ref(nrow, 1.0, b, -1.0, Ap, r); // r = b - Ax (x stored in p)
-  ComputeDotProduct_ref(nrow, r, r, &normr, t4);
+  CopyVector(x, p);
+  TICK(); ComputeSPMV_ref(A, p, Ap);  TOCK(t3); // Ap = A*p
+  TICK(); ComputeWAXPBY_ref(nrow, 1.0, b, -1.0, Ap, r); TOCK(t2); // r = b - Ax (x stored in p)
+  TICK(); ComputeDotProduct_ref(nrow, r, r, normr, t4);  TOCK(t1);
   normr = sqrt(normr);
 #ifdef HPCG_DEBUG
-  if (geom.rank==0) HPCG_fout << "Initial Residual = "<< normr << endl;
+  if (A.geom->rank==0) HPCG_fout << "Initial Residual = "<< normr << std::endl;
 #endif
 
   // Record initial residual for convergence testing
@@ -111,34 +101,31 @@ int CG_ref(const Geometry & geom, const SparseMatrix & A, CGData & data, const d
   for (int k=1; k<=max_iter && normr/normr0 > tolerance; k++ ) {
     TICK();
     if (doPreconditioning)
-      ComputeSYMGS_ref(A, r, z); // Apply preconditioner
+      ComputeMG_ref(A, r, z); // Apply preconditioner
     else
       ComputeWAXPBY_ref(nrow, 1.0, r, 0.0, r, z); // copy r to z (no preconditioning)
     TOCK(t5); // Preconditioner apply time
 
     if (k == 1) {
-      TICK(); ComputeWAXPBY_ref(nrow, 1.0, z, 0.0, z, p); TOCK(t2); // Copy Mr to p
-      TICK(); ComputeDotProduct_ref(nrow, r, z, &rtz, t4); TOCK(t1); // rtz = r'*z
+      CopyVector(z, p); TOCK(t2); // Copy Mr to p
+      TICK(); ComputeDotProduct_ref(nrow, r, z, rtz, t4); TOCK(t1); // rtz = r'*z
     } else {
       oldrtz = rtz;
-      TICK(); ComputeDotProduct_ref(nrow, r, z, &rtz, t4); TOCK(t1); // rtz = r'*z
+      TICK(); ComputeDotProduct_ref(nrow, r, z, rtz, t4); TOCK(t1); // rtz = r'*z
       beta = rtz/oldrtz;
       TICK(); ComputeWAXPBY_ref(nrow, 1.0, z, beta, p, p);  TOCK(t2); // p = beta*p + z
     }
 
-#ifndef HPCG_NOMPI
-    TICK(); ExchangeHalo(A,p); TOCK(t6);
-#endif
     TICK(); ComputeSPMV_ref(A, p, Ap); TOCK(t3); // Ap = A*p
-    TICK(); ComputeDotProduct_ref(nrow, p, Ap, &pAp, t4); TOCK(t1); // alpha = p'*Ap
+    TICK(); ComputeDotProduct_ref(nrow, p, Ap, pAp, t4); TOCK(t1); // alpha = p'*Ap
     alpha = rtz/pAp;
     TICK(); ComputeWAXPBY_ref(nrow, 1.0, x, alpha, p, x);// x = x + alpha*p
     ComputeWAXPBY_ref(nrow, 1.0, r, -alpha, Ap, r);  TOCK(t2);// r = r - alpha*Ap
-    TICK(); ComputeDotProduct_ref(nrow, r, r, &normr, t4); TOCK(t1);
+    TICK(); ComputeDotProduct_ref(nrow, r, r, normr, t4); TOCK(t1);
     normr = sqrt(normr);
 #ifdef HPCG_DEBUG
-    if (geom.rank==0 && (k%print_freq == 0 || k == max_iter))
-      HPCG_fout << "Iteration = "<< k << "   Scaled Residual = "<< normr/normr0 << endl;
+    if (A.geom->rank==0 && (k%print_freq == 0 || k == max_iter))
+      HPCG_fout << "Iteration = "<< k << "   Scaled Residual = "<< normr/normr0 << std::endl;
 #endif
     niters = k;
   }
@@ -149,9 +136,9 @@ int CG_ref(const Geometry & geom, const SparseMatrix & A, CGData & data, const d
   times[3] += t3; // SPMV time
   times[4] += t4; // AllReduce time
   times[5] += t5; // preconditioner apply time
-#ifndef HPCG_NOMPI
-  times[6] += t6; // exchange halo time
-#endif
+//#ifndef HPCG_NOMPI
+//  times[6] += t6; // exchange halo time
+//#endif
   times[0] += mytimer() - t_begin;  // Total time. All done...
   return(0);
 }
