@@ -15,5 +15,6 @@
 #ifndef EXCHANGEHALO_HPP
 #define EXCHANGEHALO_HPP
 #include "SparseMatrix.hpp"
-void ExchangeHalo(const SparseMatrix & A, const double * x);
+#include "Vector.hpp"
+void ExchangeHalo(const SparseMatrix & A, Vector & x);
 #endif // EXCHANGEHALO_HPP
