@@ -12,13 +12,6 @@
 // ***************************************************
 //@HEADER
 
-#include <ctime>
-#include <cstdio>
-#include <cstring>
-
-#include <fstream>
-#include <iostream>
-
 #ifndef HPCG_NOMPI
 #include <mpi.h>
 #endif
@@ -27,6 +20,13 @@
 #include <omp.h>
 #endif
 
+#include <ctime>
+#include <cstdio>
+#include <cstring>
+
+#include <fstream>
+#include <iostream>
+
 #include "hpcg.hpp"
 
 #include "ReadHpcgDat.hpp"
@@ -82,12 +82,12 @@ HPCG_Init(int * argc_p, char ** *argv_p, HPCG_Params & params) {
   }
 
   for (i = 0; i < 3; ++i) {
-    if (iparams[i] < 10)
+    if (iparams[i] < 16)
       for (j = 1; j <= 2; ++j)
         if (iparams[(i+j)%3] > iparams[i])
           iparams[i] = iparams[(i+j)%3];
-    if (iparams[i] < 10)
-      iparams[i] = 10;
+    if (iparams[i] < 16)
+      iparams[i] = 16;
   }
 
 #ifndef HPCG_NOMPI
@@ -117,7 +117,7 @@ HPCG_Init(int * argc_p, char ** *argv_p, HPCG_Params & params) {
 
   time ( &rawtime );
   ptm = localtime(&rawtime);
-  sprintf( fname, "hpcg_log_%04d%02d%02d_%02d:%02d:%02d.txt",
+  sprintf( fname, "hpcg_log_%04d.%02d.%02d.%02d.%02d.%02d.txt",
       1900 + ptm->tm_year, ptm->tm_mon+1, ptm->tm_mday, ptm->tm_hour, ptm->tm_min, ptm->tm_sec );
 
   if (0 == params.comm_rank)
@@ -126,7 +126,7 @@ HPCG_Init(int * argc_p, char ** *argv_p, HPCG_Params & params) {
 #if defined(HPCG_DEBUG) || defined(HPCG_DETAILED_DEBUG)
     char local[15];
     sprintf( local, "%d_", params.comm_rank );
-    sprintf( fname, "hpcg_log_%s%04d%02d%02d_%02d:%02d:%02d.txt", local,
+    sprintf( fname, "hpcg_log_%s%04.d%02d.%02d.%02d.%02d.%02d.txt", local,
         1900 + ptm->tm_year, ptm->tm_mon+1, ptm->tm_mday, ptm->tm_hour, ptm->tm_min, ptm->tm_sec );
     HPCG_fout.open(fname);
 #else
